Learn R Programming

ldamatch (version 0.6.3)

estimate_exhaustive: Estimates the maximum number of cases to be checked during exhaustive search.

Description

Estimates the maximum number of cases to be checked during exhaustive search.

Usage

estimate_exhaustive(min_preserved, condition, cases_per_second = 100,
  print_info = get("PRINT_INFO", .ldamatch_globals))

Arguments

min_preserved
Assumes that at least a total of this many subjects will be preserved.
condition
A factor vector containing condition labels.
cases_per_second
Assumes that this number of cases are checked out per second, for estimating the time it takes to run the exhaustive search; default: 100.
print_info
If TRUE, prints partial calculations as well for the number of cases and estimated time when removing 1, 2, ... subjects.

Value

  • The maximum number of cases.

Examples

Run this code
estimate_exhaustive(58, as.factor(c(rep('ALN', 25), rep('TD', 44))))
estimate_exhaustive(84, as.factor(c(rep('ASD', 51), rep('TD', 44))))

Run the code above in your browser using DataLab