Learn R Programming

ldamatch (version 0.6.3)

ks_halt: A univariate halting test using the Kolmogorov-Smirnov Test (ks.test).

Description

Note that the condition must have two levels. The null hypothesis is that they are drawn from the same distribution, so we want this to be *likely*. It is up to you to choose an appropriate threshold.

Usage

ks_halt(condition, covariates, thresh)

Arguments

condition
A factor vector containing condition labels.
covariates
A vector or columnwise matrix containing covariates to match the conditions on.
thresh
The statistical threshold to pass onto the aforementioned test.