Learn R Programming

ldamatch (version 0.6.3)

search_exhaustive: Searches the space backwards, prefering more subjects and better ratios. While the search is done in parallel, the search space is enormous and so it can be very slow in the worst case. It is perhaps most useful as a tool to study other matching procedures.

Description

Searches the space backwards, prefering more subjects and better ratios. While the search is done in parallel, the search space is enormous and so it can be very slow in the worst case. It is perhaps most useful as a tool to study other matching procedures.

Usage

search_exhaustive(sspace, condition, covariates, halting_test, thresh, props,
  print_info)

Arguments

sspace
An ordered subject subspace: a list of vectors, with one vector per group containing the corresponding subject indices.
condition
A factor vector containing condition labels.
covariates
A vector or columnwise matrix containing covariates to match the conditions on.
halting_test
A function to apply to `covariates` (in matrix form) which is TRUE iff the conditions are matched.
thresh
The statistical threshold to pass onto the aforementioned test.
props
The desired proportions (percentage) of the sample for each condition; if not specified, the (full) sample proportions are used. This is used for the "heuristic" and "exhaustive" methods.
print_info
If TRUE, prints summary information on the input and the results, as well as progress information for the exhaustive search algorithm. Default: TRUE; can be changed using set_param("PRINT_INFO

Value

  • A list of logical vector(s) for best set(s) of subjects to be kept.