Rdocumentation
powered by
Learn R Programming
ldamatch (version 0.6.3)
combine_ratios: Combines matched group candidate with current best one.
Description
Combines matched group candidate with current best one.
Usage
combine_ratios(best, candidate)
Arguments
best
The best matched groups so far together with its p-value / thresh ratio; a list containing ratio and inds (a list of subject index vectors).
candidate
A list containing ratio (a number) and ind (a vector).
Value
A structure like best containing the ind vectors with the highest ratio.