Rdocumentation
powered by
Learn R Programming
ldamatch (version 0.6.3)
search_montecarlo: Searches for a subset satisfying the test by randomly selecting subspaces of decreasing size.
Description
Searches for a subset satisfying the test by randomly selecting subspaces of decreasing size.
Usage
search_montecarlo(sspace, condition, covariates, halting_test, thresh, replicates)
Arguments
sspace
An ordered subject subspace: a list of vectors, with one vector per group containing the corresponding subject indices.
condition
A factor vector containing condition labels.
covariates
A vector or columnwise matrix containing covariates to match the conditions on.
halting_test
A function to apply to `covariates` (in matrix form) which is TRUE iff the conditions are matched.
thresh
The statistical threshold to pass onto the aforementioned test.
replicates
The maximum number of Monte Carlo replications to be performed. This is only used for the "montecarlo" method.