Rdocumentation
powered by
Learn R Programming
ldamatch (version 0.6.3)
t_halt: A univariate halting test using the t-test (t.test).
Description
A univariate halting test using the t-test (t.test).
Usage
t_halt(condition, covariates, thresh)
Arguments
condition
A factor vector containing condition labels.
covariates
A vector or columnwise matrix containing covariates to match the conditions on.
thresh
The statistical threshold to pass onto the aforementioned test.