Rdocumentation
powered by
Learn R Programming
ldamatch (version 0.6.3)
wilks_halt: A multivariate halting test (appropriate when nlevels(condition) > 2)).
Description
A multivariate halting test (appropriate when nlevels(condition) > 2)).
Usage
wilks_halt(condition, covariates, thresh)
Arguments
condition
A factor vector containing condition labels.
covariates
A vector or columnwise matrix containing covariates to match the conditions on.
thresh
The statistical threshold to pass onto the aforementioned test.